(function ($) {
$.Redactor.opts.langs['ro'] = {
	html: 'HTML',
	video: 'Adauga video...',
	image: 'Adauga imagine...',
	table: 'Tabel',
	link: 'Legatura web',
	link_insert: 'Adauga legatura web...',
	link_edit: 'Edit link',
	unlink: 'Elimina legatura web',
	formatting: 'Formatare',
	paragraph: 'Paragraf',
	quote: 'Citat',
	code: 'Cod',
	header1: 'Titlu 1',
	header2: 'Titlu 2',
	header3: 'Titlu 3',
	header4: 'Titlu 4',
	header5: 'Titlu 5',
	bold:  'Aldin (Bold)',
	italic: 'Cursiv (Italic)',
	fontcolor: 'Culoare font',
	backcolor: 'Culoare de fundal',
	unorderedlist: 'Lista neordonata',
	orderedlist: 'Lista ordonata',
	outdent: 'Redu indentarea',
	indent: 'Mareste indentarea',
	cancel: 'Renunta',
	insert: 'Adauga',
	save: 'Salveaza',
	_delete: 'Sterge',
	insert_table: 'Adauga tabel...',
	insert_row_above: 'Adauga linie deasupra',
	insert_row_below: 'Adauga linie dedesupt',
	insert_column_left: 'Adauga coloana la stanga',
	insert_column_right: 'Adauga coloana la dreapta',
	delete_column: 'Sterge coloana',
	delete_row: 'Sterge linie',
	delete_table: 'Sterge tabela',
	rows: 'Linii',
	columns: 'Coloane',
	add_head: 'Adauga cap tabel',
	delete_head: 'Sterge cap tabel',
	title: 'Titlu',
	image_position: 'Pozitie',
	none: 'None',
	left: 'Stanga',
	right: 'Dreapta',
	image_web_link: 'Legatura web imagine',
	text: 'Text',
	mailto: 'Adresa email',
	web: 'Legatura web',
	video_html_code: 'Cod adaugare video',
	file: 'Adauga fisier...',
	upload: 'Incarca',
	download: 'Descarca',
	choose: 'Alege',
	or_choose: 'sau alege din computer',
	drop_file_here: 'Trage fisierele aici',
	align_left:	'Aliniere la stanga',
	align_center: 'Centrat',
	align_right: 'Aliniere la dreapta',
	align_justify: 'Aliniere la margini',
	horizontalrule: 'Adauga rigla orizontala',
	fullscreen: 'Afisare pe tot ecranul',
	deleted: 'Taiat (Sters)',
	anchor: 'Ancora',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
