(function ($) {
$.Redactor.opts.langs['ba'] = {
	html: 'HTML',
	video: 'Ubaci video',
	image: 'Ubaci fotografiju',
	table: 'Tabela',
	link: 'Veza',
	link_insert: 'Ubaci vezu ...',
	link_edit: 'Edit link',
	unlink: 'Ukloni vezu',
	formatting: 'Stilovi',
	paragraph: 'Paragraf',
	quote: 'Citat',
	code: 'Izvorni kod',
	header1: 'Zaglavlje 1',
	header2: 'Zaglavlje 2',
	header3: 'Zaglavlje 3',
	header4: 'Zaglavlje 4',
	header5: 'Zaglavlje 5',
	bold: 'Podebljaj',
	italic: 'Nakosi',
	fontcolor: 'Boja slova',
	backcolor: 'Boja pozadine',
	unorderedlist: 'Nesortirana lista',
	orderedlist: 'Sortirana lista',
	outdent: 'Izvuci',
	indent: 'Uvuci',
	redo: 'Korak naprijed',
	undo: 'Korak nazad',
	cut: 'Izreži',
	cancel: 'Odustani',
	insert: 'Ubaci',
	save: 'Sačuvaj',
	_delete: 'Izbriši',
	insert_table: 'Ubaci tabelu',
	insert_row_above: 'Dodaj red iznad',
	insert_row_below: 'Dodaj red ispod',
	insert_column_left: 'Dodaj kolonu lijevo',
	insert_column_right: 'Dodaj kolonu desno',
	delete_column: 'Izbriši kolonu',
	delete_row: 'Izbriši red',
	delete_table: 'Izbriši tabelu',
	rows: 'Red',
	columns: 'Kolona',
	add_head: 'Dodaj zaglavlje',
	delete_head: 'Ukloni zaglavlje',
	title: 'Naslov',
	image_position: 'Pozicija',
	none: 'Bez',
	left: 'Lijevo',
	right: 'Desno',
	image_web_link: 'Web adresa fotografije',
	text: 'Tekst',
	mailto: 'Email',
	web: 'Web adresa',
	video_html_code: 'Video kod',
	file: 'Datoteka',
	upload: 'Pošalji',
	download: 'Preuzmi',
	choose: 'Odaberi',
	or_choose: 'Ili odaberi',
	drop_file_here: 'Prevuci datoteku ovdje',
	align_left:	'Poravnaj lijevo',
	align_center: 'Centriraj',
	align_right: 'Poravnaj desno',
	align_justify: 'Od ruba do ruba',
	horizontalrule: 'Ubaci horizontalnu liniju',
	fullscreen: 'Prikaz preko čitavog ekrana',
	deleted: 'Izbrisano',
	anchor: 'Sidro',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
