(function ($) {
$.Redactor.opts.langs['fr'] = {
	html: 'Code HTML',
	video: 'Insérer une vidéo...',
	image: 'Insérer une image...',
	table: 'Tableau',
	link: 'Lien',
	link_insert: 'Insérer un lien...',
	link_edit: 'Modifier le lien',
	unlink: 'Supprimer le lien',
	formatting: 'Styles',
	paragraph: 'Paragraphe',
	quote: 'Citation',
	code: 'Code',
	header1: 'Titre 1',
	header2: 'Titre 2',
	header3: 'Titre 3',
	header4: 'Titre 4',
	header5: 'Titre 5',
	bold:  'Gras',
	italic: 'Italique',
	fontcolor: 'Couleur du texte',
	backcolor: 'Couleur d\'arrière plan du texte',
	unorderedlist: 'Liste à puces',
	orderedlist: 'Liste numérotée',
	outdent: 'Diminuer le retrait',
	indent: 'Augmenter le retrait',
	cancel: 'Annuler',
	insert: 'Insérer',
	save: 'Enregistrer',
	_delete: 'Supprimer',
	insert_table: 'Insérer un tableau...',
	insert_row_above: 'Ajouter une rangée au-dessus',
	insert_row_below: 'Ajouter une rangée en-dessous',
	insert_column_left: 'Ajouter une colonne à gauche',
	insert_column_right: 'Ajouter une colonne à droite',
	delete_column: 'Supprimer la colonne',
	delete_row: 'Supprimer la rangée',
	delete_table: 'Supprimer le tableau',
	rows: 'Rangées',
	columns: 'Colonnes',
	add_head: 'Ajouter un en-tête',
	delete_head: 'Supprimer l\'en-tête',
	title: 'Titre',
	image_position: 'Position',
	none: 'Aucun',
	left: 'Gauche',
	right: 'Droite',
	image_web_link: 'Adresse URL de l\'image',
	text: 'Texte',
	mailto: 'Courriel',
	web: 'Adresse URL',
	video_html_code: 'Code d\'intégration du video',
	file: 'Insérer un fichier...',
	upload: 'Téléverser',
	download: 'Télécharger',
	choose: 'Choisir',
	or_choose: 'Ou choisissez',
	drop_file_here: 'Déposez le fichier ici',
	align_left:	'Aligner à gauche',
	align_center: 'Aligner au centre',
	align_right: 'Aligner à droite',
	align_justify: 'Justifier',
	horizontalrule: 'Insérer une ligne horizontale',
	deleted: 'Supprimé',
	anchor: 'Ancre',
	link_new_tab: 'Ouvrir le lien dans un nouvel onglet',
	underline: 'Souligner',
	alignment: 'Alignement',
	filename: 'Nom de fichier (optionnel)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );