(function ($) {
$.Redactor.opts.langs['lt'] = {
	html: 'HTML',
	video: 'Įkelti video...',
	image: 'Įkelti paveiksliuką...',
	table: 'Lentelė',
	link: 'Nuoroda',
	link_insert: 'Įtraukti nuorodą ...',
	link_edit: 'Edit link',
	unlink: 'Panaikinti nuorodą',
	formatting: 'Formatavimas',
	paragraph: 'Paragrafas',
	quote: 'Citata',
	code: 'Išnaša',
	header1: 'Antraštė 1',
	header2: 'Antraštė 2',
	header3: 'Antraštė 3',
	header4: 'Antraštė 4',
	header5: 'Antraštė 5',
	bold:  'Ryškus',
	italic: 'Pasviras',
	fontcolor: 'Teksto spalva',
	backcolor: 'Fono spalva',
	unorderedlist: 'Sąrašas',
	orderedlist: 'Numeruotas sąrašas',
	outdent: 'Pritraukti',
	indent: 'Atitraukti',
	cancel: 'Atšaukti',
	insert: 'Įterpti',
	save: 'Išsaugoti',
	_delete: 'Ištrinti',
	insert_table: 'Įtraukti lentelę...',
	insert_row_above: 'Įterpti eilutę virš',
	insert_row_below: 'Įterpti eilutę po',
	insert_column_left: 'Įterpti stulpelį kairiau',
	insert_column_right: 'Įterpti stulpelį dešiniau',
	delete_column: 'Ištrinti stulpelį',
	delete_row: 'Ištrinti eilutę',
	delete_table: 'Ištrinti lentelę',
	rows: 'Eilutės',
	columns: 'Stulpeliai',
	add_head: 'Įterpti rubriką',
	delete_head: 'Ištrinti rubriką',
	title: 'Pavadinimas',
	image_position: 'Pozicija',
	none: 'Nėra',
	left: 'Kairė',
	right: 'Dešinė',
	image_web_link: 'Nuoroda į paveiksliuką',
	text: 'Tekstas',
	mailto: 'El. paštas',
	web: 'Nuoroda',
	video_html_code: 'Video įterpimo kodas',
	file: 'Įterpti bylą...',
	upload: 'Įkelti',
	download: 'Parsisiųsti',
	choose: 'Pasirinkti',
	or_choose: 'Arba pasirinkti',
	drop_file_here: 'Mesti failą čia',
	align_left:	'Lygiuoti iš kairės',
	align_center: 'Centruoti',
	align_right: 'Lygiuoti iš dešinės',
	align_justify: 'Išlyginti eilutes',
	horizontalrule: 'Įterpti horizontalią liniją',
	deleted: 'Ištrinta',
	anchor: 'Žymė',
	link_new_tab: 'Atidaryti nuorodą naujame lange',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
