(function ($) {
$.Redactor.opts.langs['id'] = {
    html: 'HTML',
    video: 'Sisipkan Video...',
    image: 'Sisipkan Gambar...',
    table: 'Tabel',
    link: 'Tautan',
    link_insert: 'Sisipkan Tautan ...',
    link_edit: 'Edit link',
    unlink: 'Hapus Tautan',
    formatting: 'Format',
    paragraph: 'Paragraf',
    quote: 'Kutipan',
    code: 'Kode',
    header1: 'Header 1',
    header2: 'Header 2',
    header3: 'Header 3',
    header4: 'Header 4',
    header5: 'Header 5',
    bold:  'Tebal',
    italic: 'Miring',
    fontcolor: 'Warna Huruf',
    backcolor: 'Warna Latar',
    unorderedlist: 'Daftar tak berurutan',
    orderedlist: 'Daftar berurutan',
    outdent: 'Tulisan diluar',
    indent: 'Tulisan masuk',
    cancel: 'Batal',
    insert: 'Sisipkan',
    save: 'Simpan',
    _delete: 'Hapus',
    insert_table: 'Sisipkan Tabel...',
    insert_row_above: 'Tambahkan Baris di atas',
    insert_row_below: 'Tambahkan Baris di bawah',
    insert_column_left: 'Tambahkan Kolom di kiri',
    insert_column_right: 'Tambahkan Kolom di kanan',
    delete_column: 'Hapus Kolom',
    delete_row: 'Hapus Baris',
    delete_table: 'Hapus Tabel',
    rows: 'Baris',
    columns: 'Kolom',
    add_head: 'Tambahkan Head',
    delete_head: 'Hapus Head',
    title: 'Judul',
    image_position: 'Posisi',
    none: 'Kosong',
    left: 'Kiri',
    right: 'Kanan',
    image_web_link: 'Tautan Gambar Web',
    text: 'Teks',
    mailto: 'Email',
    web: 'URL',
    video_html_code: 'Kode pelekatan video',
    file: 'Sisipkan Berkas...',
    upload: 'Unggah',
    download: 'Unduh',
    choose: 'Pilih',
    or_choose: 'Atau pilih',
    drop_file_here: 'Letakkan berkas disini',
    align_left:	'Rata Kiri',
    align_center: 'Rata Tengah',
    align_right: 'Rata Kanan',
    align_justify: 'Rata Kiri dan Kanan',
    horizontalrule: 'Sisipkan garis horizontal',
    fullscreen: 'Layar penuh',
    deleted: 'Coret',
    anchor: 'Jangkar',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
