(function ($) {
    $.Redactor.opts.langs['sv'] = {
        _delete: 'Tag Bort',
        add_head: 'Lägg Till Tabellhuvud',
        align_center: 'Centerjustera',
        align_justify: 'Marginaljustering',
        align_left: 'Vänsterjustera',
        align_right: 'Högerjustera',
        alignment: 'Justering',
        anchor: 'Ankare',
        backcolor: 'Bakgrundsfärg',
        bold:  'Fet',
        cancel: 'Ångra',
        choose: 'Välj',
        code: 'Kod',
        columns: 'Kolumner',
        delete_column: 'Tag Bort Kolumn',
        delete_head: 'Tag Bort Tabellhuvud',
        delete_row: 'Tag Bort Rad',
        delete_table: 'Tag Bort Tabell',
        deleted: 'Överstruken',
        download: 'Nedladdning',
        drop_file_here: 'Släpp Fil Här',
        edit: 'Ändra',
        file: 'Infoga Fil...',
        filename: 'Namn (valfritt)',
        fontcolor: 'Typsnittsfärg',
        formatting: 'Formatering',
        fullscreen: 'Fullskärm',
        header1: 'Rubrik 1',
        header2: 'Rubrik 2',
        header3: 'Rubrik 3',
        header4: 'Rubrik 4',
        header5: 'Rubrik 5',
        horizontalrule: 'Infoga Horisontell Linje',
        html: 'HTML',
        image: 'Infoga Bild...',
        image_position: 'Position',
        image_web_link: 'Bildlänk',
        indent: 'Öka indentering',
        insert: 'Infoga',
        insert_column_left: 'Lägg Till Vänsterkolumn',
        insert_column_right: 'Lägg Till Högerkolumn',
        insert_row_above: 'Lägg Till Rad Ovanför',
        insert_row_below: 'Lägg Till Rad Under',
        insert_table: 'Infoga Tabell...',
        italic: 'Kursiv',
        left: 'Vänster',
        link: 'Länk',
        link_edit: 'Ändra länk',
        link_insert: 'Infoga Länk...',
        link_new_tab: 'Öppna länk i ny flik',
        mailto: 'E-post',
        none: 'Ingen',
        or_choose: 'Eller Välj',
        orderedlist: 'Ordnad Lista',
        outdent: 'Minska Indentering',
        paragraph: 'Paragraf',
        quote: 'Citat',
        right: 'Höger',
        rows: 'Rader',
        save: 'Spara',
        table: 'Tabell',
        text: 'Text',
        title: 'Titel',
        underline: 'Understryk',
        unlink: 'Tag Bort Länk',
        unorderedlist: 'Oordnad Lista',
        upload: 'Uppladdning',
        video: 'Infoga Video...',
        video_html_code: 'Kod För Inbäddad Video',
        web: 'Webbadress',
		center: 'Center'
    };
})( jQuery );

