(function ($) {
$.Redactor.opts.langs['es'] = {
	html: 'HTML',
	video: 'Insertar video...',
	image: 'Insertar imagen...',
	table: 'Tabla',
	link: 'Enlace',
	link_insert: 'Insertar enlace ...',
	link_edit: 'Editar enlace',
	unlink: 'Desenlazar',
	formatting: 'Estilos',
	paragraph: 'Texto normal',
	quote: 'Cita',
	code: 'Código',
	header1: 'Cabecera 1',
	header2: 'Cabecera 2',
	header3: 'Cabecera 3',
	header4: 'Cabecera 4',
	header5: 'Cabecera 5',
	bold:  'Negrita',
	italic: 'Itálica',
	fontcolor: 'Color de fuente',
	backcolor: 'Color de fondo',
	unorderedlist: 'Lista desordenada',
	orderedlist: 'Lista ordenada',
	outdent: 'Disminuir sangrado',
	indent: 'Aumentar sangrado',
	cancel: 'Cancelar',
	insert: 'Insertar',
	save: 'Guardar',
	_delete: 'Borrar',
	insert_table: 'Insertar tabla...',
	insert_row_above: 'Añadir fila encima',
	insert_row_below: 'Añadir fila debajo',
	insert_column_left: 'Añadir columna a la izquierda',
	insert_column_right: 'Añadir column a la derecha',
	delete_column: 'Borrar columna',
	delete_row: 'Borrar fila',
	delete_table: 'Borrar tabla',
	rows: 'Filas',
	columns: 'Columnas',
	add_head: 'Añadir cabecera',
	delete_head: 'Borrar cabecera',
	title: 'Título',
	image_position: 'Posición',
	none: 'Ninguna',
	left: 'Izquierda',
	right: 'Derecha',
	image_web_link: 'Enlace web de la imágen',
	text: 'Texto',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Código de inserción de video',
	file: 'Insertar archivo...',
	upload: 'Cargar',
	download: 'Descargar',
	choose: 'Elegir',
	or_choose: 'O elegir',
	drop_file_here: 'Arrastra y suelta el archivo aqui',
	align_left:	'Alinear texto a la izquierda',
	align_center: 'Centrar texto',
	align_right: 'Alinear texto a la derecha',
	align_justify: 'Justificar texto',
	horizontalrule: 'Insertar línea horizontal',
	deleted: 'Borrado',
	anchor: 'Anchor',
	link_new_tab: 'Abrir enlace en una nueva pestaña',
	underline: 'Subrayado',
	alignment: 'Alineación',
	filename: 'Nombre (opcional)',
	edit: 'Editar',
	center: 'Center'
};
})( jQuery );