(function ($) {
$.Redactor.opts.langs['ar'] = {
	html: 'كود HTML',
	video: 'إدراج فيديو...',
	image: 'إدراج صورة...',
	table: 'جدول',
	link: 'رابط',
	link_insert: 'إدراج رابط...',
	link_edit: 'تحرير الرابط',
	unlink: 'إزالة الرابط',
	formatting: 'التنسيق',
	paragraph: 'نص عادي',
	quote: 'اقتباس',
	code: 'كود',
	header1: 'العنوان 1',
	header2: 'العنوان 2',
	header3: 'العنوان 3',
	header4: 'العنوان 4',
	header5: '5 العنوان',
	bold:  'متين',
	italic: 'مائل',
	fontcolor: 'لون الخط',
	backcolor: 'لون الخلفية',
	unorderedlist: 'قائمة منقطة',
	orderedlist: 'قائمة رقمية',
	outdent: 'أزل المسافة البادئة',
	indent: 'أضف المسافة البادئة',
	cancel: 'إلغاء',
	insert: 'إدراج',
	save: 'حفظ',
	_delete: 'حذف',
	insert_table: 'إدراج جدول...',
	insert_row_above: 'إضافة صف للأعلى',
	insert_row_below: 'إضافة صف للأسفل',
	insert_column_left: 'إضافة عمود لليسار',
	insert_column_right: 'إضافة عمود لليمين',
	delete_column: 'حذف العمود',
	delete_row: 'حذف الصف',
	delete_table: 'حذف الجدول',
	rows: 'الصفوف',
	columns: 'الأعمدة',
	add_head: 'إضافة رأس',
	delete_head: 'حذف رأس',
	title: 'العنوان',
	image_position: 'الموضع',
	none: 'بدون',
	left: 'يسار',
	right: 'يمين',
	image_web_link: 'رابط الصورة',
	text: 'نص',
	mailto: 'بريد الكتروني',
	web: 'رابط',
	video_html_code: 'كود الفيديو',
	file: 'إدراج ملف...',
	upload: 'تحميل',
	download: 'تنزيل',
	choose: 'اختيار',
	or_choose: 'أو اختيار',
	drop_file_here: 'اسحب الملف هنا',
	align_left:	'محاذاة النص الى اليسار',
	align_center: 'محاذاة النص الى الوسط',
	align_right: 'محاذاة النص الى اليمين',
	align_justify: 'ضبط النص',
	horizontalrule: 'إدراج خط فاصل',
	fullscreen: 'ملء الشاشة',
	deleted: 'محذوف',
	anchor: 'مرساة',
	link_new_tab: 'فتح الرابط في تبويب جديد',
	underline: 'مسطر',
	alignment: 'محاذاة',
	filename: 'الاسم (اختياري)',
	edit: 'تحرير',
	center: 'توسيط'
};
})( jQuery );