(function ($) {
$.Redactor.opts.langs['mk'] = {
	html: 'HTML',
	video: 'Внеси видео...',
	image: 'Внеси слика...',
	table: 'Табела',
	link: 'Линк',
	link_insert: 'Внеси линк ...',
	link_edit: 'Edit link',
	unlink: 'Избриши линк',
	formatting: 'Форматирање',
	paragraph: 'Параграф',
	quote: 'Цитат',
	code: 'Код',
	header1: 'Заглавие 1',
	header2: 'Заглавие 2',
	header3: 'Заглавие 3',
	header4: 'Заглавие 4',
	header5: 'Заглавие 5',
	bold:  'Болдирано',
	italic: 'Италик',
	fontcolor: 'Боја на фонт',
	backcolor: 'Боја на позадина',
	unorderedlist: 'Неподредена листа',
	orderedlist: 'Подредена листа',
	outdent: 'Нанадвор',
	indent: 'Навнатре',
	cancel: 'Откажи',
	insert: 'Внеси',
	save: 'Зачувај',
	_delete: 'Избриши',
	insert_table: 'Внеси табела...',
	insert_row_above: 'Додај ред над',
	insert_row_below: 'Додај ред под',
	insert_column_left: 'Додај колона лево',
	insert_column_right: 'Додај колона десно',
	delete_column: 'Избриши колона',
	delete_row: 'Избриши ред',
	delete_table: 'Избриши табела',
	rows: 'Редови',
	columns: 'Колони',
	add_head: 'Додај наслов',
	delete_head: 'Избриши наслов',
	title: 'Наслов',
	image_position: 'Позиција',
	none: 'Не позиционирај',
	left: 'Лево',
	right: 'Десно',
	image_web_link: 'Слика од линк',
	text: 'Текст',
	mailto: 'Е-маил',
	web: 'URL',
	video_html_code: 'Код за видео',
	file: 'Внеси фајл...',
	upload: 'Качи на сервер',
	download: 'Симни',
	choose: 'Одбери',
	or_choose: 'Или одбери',
	drop_file_here: 'Спушти фајл тука',
	align_left:	'Порамни текст на лево',
	align_center: 'Центрирај текст',
	align_right: 'Порамни текст на десно',
	align_justify: 'Израмни текси',
	horizontalrule: 'Внеси хоризонтална линија',
	deleted: 'Избришано',
	anchor: 'Локален линк',
	link_new_tab: 'Отвори линк во нов таб',
	underline: 'Подвлечи',
	alignment: 'Порамнување',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
