(function ($) {
	$.Redactor.opts.langs['no_NB'] = {
		html: 'HTML',
		video: 'Sett inn video...',
		image: 'Sett inn bilde...',
		table: 'Tabell',
		link: 'Link',
		link_insert: 'Sett inn link...',
		link_edit: 'Rediger link',
		unlink: 'Fjern link',
		formatting: 'Formatering',
		paragraph: 'Avsnitt',
		quote: 'Sitat',
		code: 'Kode',
		header1: 'Overskrift 1',
		header2: 'Overskrift 2',
		header3: 'Overskrift 3',
		header4: 'Overskrift 4',
		header5: 'Overskrift 5',
		bold: 'Fet',
		italic: 'Kursiv',
		fontcolor: 'Tekstfarge',
		backcolor: 'Bakgrunsfarge',
		unorderedlist: 'Usortert liste',
		orderedlist: 'Sortert liste',
		outdent: 'Redusere innrykk',
		indent: 'Innrykk',
		cancel: 'Avbryt',
		insert: 'Sett inn',
		save: 'Lagre',
		_delete: 'Slett',
		insert_table: 'Sett inn tabell...',
		insert_row_above: 'Legg til rad over',
		insert_row_below: 'Legg til rad under',
		insert_column_left: 'Legg til kolonne venstre',
		insert_column_right: 'Legg til kolonne h&oslash;yre',
		delete_column: 'Slett kolonne',
		delete_row: 'Slett rad',
		delete_table: 'Slett tabell',
		rows: 'Rader',
		columns: 'Kolonner',
		add_head: 'Legg til tabellhode',
		delete_head: 'Slett tabellhode',
		title: 'Tittel',
		image_position: 'Plassering',
		none: 'Ingen',
		left: 'venstre',
		right: 'H&oslash;yre',
		image_web_link: 'Bildelink',
		text: 'Tekst',
		mailto: 'E-Post',
		web: 'URL',
		video_html_code: 'Kode for innbyggingsvideo',
		file: 'Sett inn fil...',
		upload: 'Last opp',
		download: 'Last ned',
		choose: 'Velg',
		or_choose: 'Eller velg',
		drop_file_here: 'Slipp filen her',
		align_left: 'Venstrejuster',
		align_center: 'Midtjuster',
		align_right: 'H&oslash;yrejuster',
		align_justify: 'Balansert',
		horizontalrule: 'Sett inn horisontal linje',
		deleted: 'Slettet',
		anchor: 'Anker',
		link_new_tab: '&Aring;pne link i ny fane',
		underline: 'Understreking',
		alignment: 'Justering',
		filename: 'Filnavn (valgfritt)',
		edit: 'Edit',
		center: 'Center'
	};
})(jQuery);